@@ -6,7 +6,6 @@ Wallpaper and colour manager for Sway, i3 and some other WMs, as a frontend to s
 
 Author: Piotr Miller & Contributors
 e-mail: nwg.piotr@gmail.com
-Website: http://nwg.pl
 Project: https://github.com/nwg-piotr/azote
 License: GPL3
 
@@ -44,13 +43,22 @@ from azote.plugins import Alacritty, Xresources
 from azote.color_tools import WikiColours
 
 try:
-    gi.require_version('AppIndicator3', '0.1')
-    from gi.repository import AppIndicator3
+    try:
+        gi.require_version('AppIndicator3', '0.1')
+        from gi.repository import AppIndicator3
 
-    common.env['app_indicator'] = True
-except:
+        common.env['app_indicator'] = True
+        common.env['app_indicator_library'] = 'AppIndicator3'
+    except (ImportError, ValueError):
+        gi.require_version('AyatanaAppIndicator3', '0.1')
+        from gi.repository import AyatanaAppIndicator3 as AppIndicator3
+
+        common.env['app_indicator'] = True
+        common.env['app_indicator_library'] = 'AyatanaAppIndicator3'
+except Exception as e:
     common.env['app_indicator'] = False
-    print('libappindicator-gtk3 package not found - tray icon unavailable')
+    common.env['app_indicator_library'] = None
+    print('Neither libappindicator-gtk3 nor libayatana-appindicator3 package found - tray icon unavailable')
 
 from azote.__about__ import __version__
 
@@ -466,7 +474,7 @@ def on_apply_button(button):
                     display_name = box.display_name
 
                 # Escape some special characters which would mess up the script
-                wallpaper_path = box.wallpaper_path.replace('\\', '\\\\').replace("$", "\$").replace("`",
+                wallpaper_path = box.wallpaper_path.replace('\\', '\\\\').replace("$", "\\$").replace("`",
                                                                                                      "\\`").replace('"',
                                                                                                                     '\\"')
 
@@ -610,7 +618,7 @@ def on_about_button(button):
                         '- maim, slop (c) 2014 Dalton Nell and Contributors',
                         '- imagemagick (c) 1999-2019 ImageMagick Studio LLC',
                         '- PyYAML (c) 2017-2019 Ingy döt Net Copyright (c) 2006-2016 Kirill Simonov'])
-    dialog.set_translator_credits('xsme, Leon-Plickat (de_DE), HumanG33k (fr_FR)')
+    dialog.set_translator_credits('xsme, Leon-Plickat (de_DE), HumanG33k (fr_FR), Andrea Frati (it_IT),\nMarcelo dos Santos (pt_BR), Aleksey Samoilov (ru_RU)')
     dialog.set_artists(['edskeye'])
 
     dialog.show()
@@ -1126,7 +1134,7 @@ def pick_color():
     if common.sway or common.env['wayland']:
         try:
             color = hex_to_rgb(subprocess.check_output(
-                'grim -g "$(slurp -p)" -t ppm - | convert - -format \'%[pixel:p{0,0}]\' txt:- | awk \'NR==2 {print $3}\'',
+                'grim -g "$(slurp -p)" -t ppm - | magick - -format \'%[pixel:p{0,0}]\' txt:- | awk \'NR==2 {print $3}\'',
                 shell=True).decode("utf-8"))
         except:
             try:
@@ -1135,7 +1143,7 @@ def pick_color():
                 pass
     else:
         try:
-            output = subprocess.check_output('maim -st 0 | convert - -resize 1x1! -format \'%[pixel:p{0,0}]\' info:-',
+            output = subprocess.check_output('maim -st 0 | magick - -resize 1x1! -format \'%[pixel:p{0,0}]\' info:-',
                                              shell=True).decode("utf-8")
             values = output[6:-1].split(",")
             color = (int(values[0]), int(values[1]), int(values[2]))
